==> docx4j-openxml-objects-pml-8.3.1-sources.jar: org/pptx4j/com/microsoft/schemas/office/powerpoint/x2010/main/CTRevealTransition.java <==

package org.pptx4j.com.microsoft.schemas.office.powerpoint.x2010.main;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_RevealTransition complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_RevealTransition"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="thruBlk" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="dir" type="{http://schemas.microsoft.com/office/powerpoint/2010/main}ST_TransitionLeftRightDirectionType" default="l" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_RevealTransition")
public class CTRevealTransition implements Child
{

    @XmlAttribute(name = "thruBlk")
    protected Boolean thruBlk;
    @XmlAttribute(name = "dir")
    protected STTransitionLeftRightDirectionType dir;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the thruBlk property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isThruBlk() {
        if (thruBlk == null) {
            return false;
        } else {
            return thruBlk;
        }
    }

    /**
     * Sets the value of the thruBlk property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setThruBlk(Boolean value) {
        this.thruBlk = value;
    }

    /**
     * Gets the value of the dir property.
     * 
     * @return
     *     possible object is
     *     {@link STTransitionLeftRightDirectionType }
     *     
     */
    public STTransitionLeftRightDirectionType getDir() {
        if (dir == null) {
            return STTransitionLeftRightDirectionType.L;
        } else {
            return dir;
        }
    }

    /**
     * Sets the value of the dir property.
     * 
     * @param value
     *     allowed object is
     *     {@link STTransitionLeftRightDirectionType }
     *     
     */
    public void setDir(STTransitionLeftRightDirectionType value) {
        this.dir = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-pml-11.4.8-sources.jar: org/pptx4j/com/microsoft/schemas/office/powerpoint/x2010/main/CTRevealTransition.java <==

package org.pptx4j.com.microsoft.schemas.office.powerpoint.x2010.main;

import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_RevealTransition complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_RevealTransition"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="thruBlk" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="dir" type="{http://schemas.microsoft.com/office/powerpoint/2010/main}ST_TransitionLeftRightDirectionType" default="l" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_RevealTransition")
public class CTRevealTransition implements Child
{

    @XmlAttribute(name = "thruBlk")
    protected Boolean thruBlk;
    @XmlAttribute(name = "dir")
    protected STTransitionLeftRightDirectionType dir;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the thruBlk property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isThruBlk() {
        if (thruBlk == null) {
            return false;
        } else {
            return thruBlk;
        }
    }

    /**
     * Sets the value of the thruBlk property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setThruBlk(Boolean value) {
        this.thruBlk = value;
    }

    /**
     * Gets the value of the dir property.
     * 
     * @return
     *     possible object is
     *     {@link STTransitionLeftRightDirectionType }
     *     
     */
    public STTransitionLeftRightDirectionType getDir() {
        if (dir == null) {
            return STTransitionLeftRightDirectionType.L;
        } else {
            return dir;
        }
    }

    /**
     * Sets the value of the dir property.
     * 
     * @param value
     *     allowed object is
     *     {@link STTransitionLeftRightDirectionType }
     *     
     */
    public void setDir(STTransitionLeftRightDirectionType value) {
        this.dir = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
